#!/usr/bin/zsh

# check for sudo
if [ "$USER" != "root" ]; then
    sudo="sudo"
else
    sudo=""
fi

# APT/NALA - Debian
if command -v nala >/dev/null 2>&1; then
    pkg="$sudo nala"
    install="$pkg update && $pkg install"
    remove="$pkg prune"
    update="$pkg update && $pkg upgrade"
    ref="$pkg update --assume-yes"
    search="$pkg search"
elif command -v apt-get >/dev/null 2>&1; then
    pkg="$sudo apt-get"
    install="$pkg update && $pkg install"
    remove="$pkg remove"
    update="$pkg update && $pkg upgrade"
    ref="$pkg update --assume-yes"
    search="$pkg search"
fi

# DNF - Fedora
if command -v dnf >/dev/null 2>&1;  then
    pkg="$sudo dnf"
    install="$pkg install"
    remove="$pkg remove"
    update="$pkg update"
    ref="$update"
    search="$pkg search"
fi

# Pacman - Arch
if command -v paru >/dev/null 2>&1; then
    pkg="paru"
    install="$pkg -S"
    remove="$pkg -R"
    update="$pkg -Syu"
    ref="$pkg -S --noconfirm"
    search="$pkg -Ss"
elif command -v yay >/dev/null 2>&1; then
    pkg="yay"
    install="$pkg -S"
    remove="$pkg -R"
    update="$pkg -Syu"
    ref="$pkg -Sy --noconfirm"
    search="$pkg -Ss"
elif command -v pacman >/dev/null 2>&1; then
    pkg="$sudo pacman"
    install="$pkg -S"
    remove="$pkg -R"
    update="$pkg -Syu"
    ref="$pkg -Sy --needet --noconfirm"
    search="$pkg -Ss"
fi


# Zypper - OpenSuse
if command -v zypper >/dev/null 2>&1; then
    pkg="$sudo zypper"
    install="$pkg install"
    remove="$pkg remove"
    update="$pkg dup"
    ref="$pkg refresh"
    search="$pkg search"
fi

# APK - Alpine
if command -v apk >/dev/null 2>&1; then
    pkg="$sudo apk"
    install="$pkg add"
    update="$pkg upgrade"
    ref="$pkg update"
    search="$pkg search"
fi

ZSH_INSTALL="$install"
ZSH_UPDATE="$ref"

alias install="$install"
alias update="$update"
alias remove="$remove"
alias refresh="$ref"
alias search="$search"
